@@ -1,9 +1,18 @@
-from Products.CMFCore.utils import getToolByName
 from plone.app.layout.dashboard.dashboard import DashboardView
 from plone.portlets.interfaces import IPortletType
+from Products.CMFCore.utils import getToolByName
 from zope.component import queryUtility
 
 
+# Try to get the plone.protect's createToken method, because it's only
+# available since version 2.0.2, otherwise we just use a mocked method.
+try:
+    from plone.protect import createToken
+except ImportError:
+    def createToken():
+        return ''
+
+
 class FTWDashBoard(DashboardView):
     """ Improve the default Plone Dashboard """
 
@@ -24,9 +33,16 @@ class FTWDashBoard(DashboardView):
         else:
             request.set('disable_plone.rightcolumn', False)
 
+    def authenticator_token(self):
+        return createToken()
+
     def dashboard_props(self):
         return getattr(self.context.portal_properties, 'ftw.dashboard', None)
 
+    @property
+    def editable(self):
+        return self.props.getProperty('dashboardEditable', False)
+
     def add_portlet_options(self):
         mtool = getToolByName(self.context, 'portal_membership')
         userid = mtool.getAuthenticatedMember().getId()
